@@ -30,6 +30,10 @@ if ! $DUB describe --compiler=$DC --filter-versions \
     --data=pre-build-commands \
     --data=post-build-commands \
     '--data=requirements, options' \
+    --data=default-config \
+    --data=configs \
+    --data=default-build \
+    --data=builds \
     > "$temp_file"; then
     die $LINENO 'Printing project data failed!'
 fi
@@ -122,16 +126,45 @@ echo >> "$expected_file"
 # --data=requirements
 echo "allowWarnings" >> "$expected_file"
 echo "disallowInlining" >> "$expected_file"
-#echo "requireContracts" >> "$expected_file"  # Not sure if this (from a sourceLib dependency) should be missing from the result
+echo "requireContracts" >> "$expected_file"
 echo >> "$expected_file"
 # --data=options
 echo "debugMode" >> "$expected_file"
-echo "releaseMode" >> "$expected_file"
+# releaseMode is not included, even though it's specified, because the requireContracts requirement drops it
 echo "debugInfo" >> "$expected_file"
+echo "stackStomping" >> "$expected_file"
 echo "warnings" >> "$expected_file"
-#echo "stackStomping" >> "$expected_file"  # Not sure if this (from a sourceLib dependency) should be missing from the result
+echo >> "$expected_file"
+# --data=default-config
+echo "my-project-config" >> "$expected_file"
+echo >> "$expected_file"
+# --data=configs
+echo "my-project-config" >> "$expected_file"
+echo >> "$expected_file"
+# --data=default-build
+echo "debug" >> "$expected_file"
+echo >> "$expected_file"
+# --data=builds
+echo "debug" >> "$expected_file"
+echo "plain" >> "$expected_file"
+echo "release" >> "$expected_file"
+echo "release-debug" >> "$expected_file"
+echo "release-nobounds" >> "$expected_file"
+echo "unittest" >> "$expected_file"
+echo "profile" >> "$expected_file"
+echo "profile-gc" >> "$expected_file"
+echo "docs" >> "$expected_file"
+echo "ddox" >> "$expected_file"
+echo "cov" >> "$expected_file"
+echo "cov-ctfe" >> "$expected_file"
+echo "unittest-cov" >> "$expected_file"
+echo "unittest-cov-ctfe" >> "$expected_file"
+echo "syntax" >> "$expected_file"
+# echo >> "$expected_file"
 
 if ! diff "$expected_file" "$temp_file"; then
+    echo "Result:"
+    cat "$temp_file"
     die $LINENO 'The project data did not match the expected output!'
 fi
 
