@@ -1,7 +1,10 @@
 #!/usr/bin/env bash
 
 . $(dirname "${BASH_SOURCE[0]}")/common.sh
-if [ "${DC}" != "dmd" ]; then
+
+if [ $(uname) != "Linux" ]; then
+    echo "Skipping issue782-dtkd-pkg-config test on non-Linux platform..."
+elif [ "${DC}" != "dmd" ]; then
 	echo "Skipping issue782-dtkd-pkg-config test for ${DC}..."
 else
     echo ${CURR_DIR-$(pwd)}
