@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-set -e
+. $(dirname "${BASH_SOURCE[0]}")/common.sh
 
 TMPDIR=${CURR_DIR}tmppack
 echo $TMPDIR
@@ -9,9 +9,11 @@ mkdir ${TMPDIR}
 cd ${TMPDIR}
 
 # kill dub init during interactive mode
-${DUB} init < /dev/stdin &
+mkfifo in
+${DUB} init < in &
 sleep 1
 kill $!
+rm in
 
 # ensure that no files are left behind
 NFILES_PLUS_ONE=`ls -la | wc -l`
@@ -21,5 +23,5 @@ rm -r ${TMPDIR}
 
 # ignore sum + "." + ".."
 if [ ${NFILES_PLUS_ONE} -gt 3 ]; then
-	exit 1;
+    die $LINENO 'Aborted dub init left spurious files around.'
 fi
